fricas: A general purpose computer algebra system
=================================================

Description
-----------

FriCAS is a general purpose computer algebra system.

License
-------

Modified BSD license.


Upstream Contact
----------------

https://github.com/fricas/fricas
